@@ -1,7 +1,7 @@
 `vcov.cusp` <-
 function (object, ...) 
 {
-    so <- summary.cusp(object, corr = FALSE, logist = FALSE, 
+    so <- summary.cusp(object, correlation = FALSE, logist = FALSE, 
         ...)
     so$dispersion * so$cov.unscaled
 }
